Changelog
=========

2.1.0 (2014-09-04)
------------------
    - Add support for Django 1.7.

2.0.0 (2014-07-13)
------------------
    - Renamed top-level namespace to ``livefield``.
    - Restructured internally to match Django convention.
    - Added GIS support.
    - Added South support.

1.0.0 (2014-02-14)
------------------
    - Initial release.
    - Separated existing code from main application repository.
